aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGravatar Tom Willemse2024-03-12 11:36:32 -0700
committerGravatar Tom Willemse2024-03-12 11:36:32 -0700
commit15e555bb5e09eaea982b6881f889d2df3517048b (patch)
treee766a5aab120f9646215b4839c80b6d1809fa7de
parent2011414821fb9175c4958bb247d0f1fc52b6fbfc (diff)
downloademacs-config-15e555bb5e09eaea982b6881f889d2df3517048b.tar.gz
emacs-config-15e555bb5e09eaea982b6881f889d2df3517048b.zip
Add Stuck projects and overview agenda commands
-rw-r--r--oni-org/oni-org.el19
1 files changed, 17 insertions, 2 deletions
diff --git a/oni-org/oni-org.el b/oni-org/oni-org.el
index beef7b9..8fd65ec 100644
--- a/oni-org/oni-org.el
+++ b/oni-org/oni-org.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2024.0201.164329
;; Package-Requires: (oni-yasnippet oni-alert oni-hydra org org-bullets org-edna diminish all-the-icons olivetti form-feed org-pretty-table ob-async)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -47,7 +47,9 @@
(require 'org-faces)
(require 'org-habit)
(require 'org-protocol)
+(require 'org-ql)
(require 'org-roam)
+(require 'org-super-agenda)
(require 'range)
(require 'subr-x)
(require 'yasnippet)
@@ -555,6 +557,7 @@ also move point to the start of the heading."
(add-hook 'org-mode-hook 'yas-minor-mode)
(org-edna-mode)
+(org-super-agenda-mode)
(unless (eq system-type 'windows-nt)
(require 'org-bullets)
@@ -1226,6 +1229,18 @@ same code all the time."
(map-insert ,collection ,key-name ,value-name))
,value-name)))))
+(oni-org--map-put org-agenda-custom-commands "P"
+ '("Stuck projects" ((org-ql-block '(and (todo) (children (not (todo))))))))
+
+(oni-org--map-put org-agenda-custom-commands "o"
+ '("Overview" ((org-ql-block '(and (todo) (children (not (todo))))
+ ((org-ql-block-header "Stuck projects")))
+ (org-ql-block '(and (todo) (not (children)))
+ ((org-super-agenda-groups '((:auto-parent)))
+ (org-ql-block-header "Todo")))
+ (agenda ""
+ ((org-agenda-span 3))))))
+
(oni-org--map-put org-capture-templates "t"
'("A simple TODO item." entry (file "") "* TODO %?
:PROPERTIES:
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 2024.0201.164329
-;; Package-Requires: (oni-yasnippet oni-alert oni-hydra org org-bullets org-edna diminish all-the-icons olivetti form-feed org-pretty-table ob-async)
+;; Version: 2024.0312.113546
+;; Package-Requires: (oni-yasnippet oni-alert oni-hydra org org-bullets org-edna diminish all-the-icons olivetti form-feed org-pretty-table ob-async org-ql org-super-agenda)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by